@@ -2,11 +2,12 @@ package Perl::PrereqScanner::Lite;
 use 5.008005;
 use strict;
 use warnings;
+use Carp ();
 use Compiler::Lexer;
 use CPAN::Meta::Requirements;
 use Perl::PrereqScanner::Lite::Constants;
 
-our $VERSION = "0.23";
+our $VERSION = "0.24";
 
 sub new {
     my ($class, $opt) = @_;
@@ -19,9 +20,29 @@ sub new {
         $lexer = Compiler::Lexer->new(),
     }
 
+    my $extra_scanners = [];
+    if (my $scanner_names = $opt->{extra_scanners}) {
+        if (ref $scanner_names eq 'ARRAY') {
+            for my $scanner_name (@$scanner_names) {
+                my $extra_scanner;
+                if (substr($scanner_name, 0, 1) eq '+') {
+                    $extra_scanner = substr $scanner_name, 1;
+                }
+                else {
+                    $extra_scanner = "Perl::PrereqScanner::Lite::Scanner::$scanner_name";
+                }
+
+                eval "require $extra_scanner"; ## no critic
+                push @$extra_scanners, $extra_scanner;
+            }
+        } else {
+            Carp::croak "'extra_scanners' option must be array reference";
+        }
+    }
+
     bless {
         lexer          => $lexer,
-        extra_scanners => [],
+        extra_scanners => $extra_scanners,
         module_reqs    => CPAN::Meta::Requirements->new,
     }, $class;
 }
@@ -29,7 +50,14 @@ sub new {
 sub add_extra_scanner {
     my ($self, $scanner_name) = @_;
 
-    my $extra_scanner = "Perl::PrereqScanner::Lite::Scanner::$scanner_name";
+    my $extra_scanner;
+    if (substr($scanner_name, 0, 1) eq '+') {
+        $extra_scanner = substr $scanner_name, 1;
+    }
+    else {
+        $extra_scanner = "Perl::PrereqScanner::Lite::Scanner::$scanner_name";
+    }
+
     eval "require $extra_scanner"; ## no critic
     push @{$self->{extra_scanners}}, $extra_scanner;
 }
@@ -281,15 +309,6 @@ sub _scan {
                 next;
             }
 
-            # XXX Workaround for v-strings which has underscore at tail (e.g. v1.1_1).
-            # It is a matter of Compiler::Lexer.
-            #
-            # ref: https://github.com/moznion/Perl-PrereqScanner-Lite/issues/6
-            if ($is_prev_version && $token_type == KEY) {
-                $module_version .= $token->{data};
-                next;
-            }
-
             if ($token_type != WHITESPACE) {
                 $does_garbage_exist  = 1;
                 $is_prev_module_name = 0;
@@ -328,6 +347,8 @@ __END__
 
 =encoding utf-8
 
+=for stopwords prepend
+
 =head1 NAME
 
 Perl::PrereqScanner::Lite - Lightweight Prereqs Scanner for Perl
@@ -337,7 +358,7 @@ Perl::PrereqScanner::Lite - Lightweight Prereqs Scanner for Perl
     use Perl::PrereqScanner::Lite;
 
     my $scanner = Perl::PrereqScanner::Lite->new;
-    $scanner->add_extra_scanner('Moose');
+    $scanner->add_extra_scanner('Moose'); # add extra scanner for moose style
     my $modules = $scanner->scan_file('path/to/file');
 
 =head1 DESCRIPTION
@@ -347,17 +368,37 @@ This scanner uses L<Compiler::Lexer> as tokenizer, therefore processing speed is
 
 =head1 METHODS
 
+=head2 new($opt)
+
+Create a scanner instance.
+
+C<$opt> must be hash reference. It accepts following keys of hash:
+
 =over 4
 
-=item * new($opt)
+=item * extra_scanners
 
-Create scanner instance.
+It specifies extra scanners. This item must be array reference.
 
-=item * scan_file($file_path)
+e.g.
+
+    my $scanner = Perl::PrereqScanner::Lite->new(
+        extra_scanners => [qw/Moose Version/]
+    );
+
+See also L</add_extra_scanner($scanner_name)>.
+
+=item * no_prereq
+
+It specifies to use C<## no prereq> or not. Please see also L</ADDITIONAL NOTATION>.
+
+=back
+
+=head2 scan_file($file_path)
 
 Scan and figure out prereqs which is instance of C<CPAN::Meta::Requirements> by file path.
 
-=item * scan_string($string)
+=head2 scan_string($string)
 
 Scan and figure out prereqs which is instance of C<CPAN::Meta::Requirements> by source code string written in perl.
 
@@ -367,7 +408,7 @@ e.g.
     my $string = do { local $/; <$fh> };
     my $modules = $scanner->scan_string($string);
 
-=item * scan_module($module_name)
+=head2 scan_module($module_name)
 
 Scan and figure out prereqs which is instance of C<CPAN::Meta::Requirements> by module name.
 
@@ -375,7 +416,7 @@ e.g.
 
     my $modules = $scanner->scan_module('Perl::PrereqScanner::Lite');
 
-=item * scan_tokens($tokens)
+=head2 scan_tokens($tokens)
 
 Scan and figure out prereqs which is instance of C<CPAN::Meta::Requirements> by tokens of L<Compiler::Lexer>.
 
@@ -386,10 +427,12 @@ e.g.
     my $tokens = Compiler::Lexer->new->tokenize($string);
     my $modules = $scanner->scan_tokens($tokens);
 
-=item * add_extra_scanner($scanner_name)
+=head2 add_extra_scanner($scanner_name)
 
 Add extra scanner to scan and figure out prereqs. This module loads extra scanner such as C<Perl::PrereqScanner::Lite::Scanner::$scanner_name> if specifying scanner name through this method.
 
+If you want to specify an extra scanner from external package without C<Perl::PrereqScanner::Lite::> prefix, you can prepend C<+> to C<$scanner_name>. Like so C<+Your::Awesome::Scanner>.
+
 Extra scanners that are default supported are followings;
 
 =over 8
@@ -400,8 +443,6 @@ Extra scanners that are default supported are followings;
 
 =back
 
-=back
-
 =head1 ADDITIONAL NOTATION
 
 If C<no_prereq> is enabled by C<new()> (like so: C<Perl::PrereqScanner::Lite-E<gt>new({no_prereq =E<gt> 1})>),
